==> libvisio-0.1.10-1-x86_64.pkg.tar.zst: usr/share/doc/libvisio/html/annotated_dup.js <==
var annotated_dup =
[
    [ "libvisio", "namespacelibvisio.html", [
      [ "ChunkHeader", "structlibvisio_1_1ChunkHeader.html", "structlibvisio_1_1ChunkHeader" ],
      [ "Colour", "structlibvisio_1_1Colour.html", "structlibvisio_1_1Colour" ],
      [ "EndOfStreamException", "classlibvisio_1_1EndOfStreamException.html", null ],
      [ "ForeignData", "structlibvisio_1_1ForeignData.html", "structlibvisio_1_1ForeignData" ],
      [ "GenericException", "classlibvisio_1_1GenericException.html", null ],
      [ "NURBSData", "structlibvisio_1_1NURBSData.html", "structlibvisio_1_1NURBSData" ],
      [ "Pointer", "structlibvisio_1_1Pointer.html", "structlibvisio_1_1Pointer" ],
      [ "PolylineData", "structlibvisio_1_1PolylineData.html", "structlibvisio_1_1PolylineData" ],
      [ "VDXParser", "classlibvisio_1_1VDXParser.html", "classlibvisio_1_1VDXParser" ],
      [ "VisioDocument", "classlibvisio_1_1VisioDocument.html", "classlibvisio_1_1VisioDocument" ],
      [ "VSD5Parser", "classlibvisio_1_1VSD5Parser.html", "classlibvisio_1_1VSD5Parser" ],
      [ "VSD6Parser", "classlibvisio_1_1VSD6Parser.html", "classlibvisio_1_1VSD6Parser" ],
      [ "VSDArcTo", "classlibvisio_1_1VSDArcTo.html", "classlibvisio_1_1VSDArcTo" ],
      [ "VSDBullet", "structlibvisio_1_1VSDBullet.html", "structlibvisio_1_1VSDBullet" ],
      [ "VSDCharacterList", "classlibvisio_1_1VSDCharacterList.html", "classlibvisio_1_1VSDCharacterList" ],
      [ "VSDCharacterListElement", "classlibvisio_1_1VSDCharacterListElement.html", "classlibvisio_1_1VSDCharacterListElement" ],
      [ "VSDCharIX", "classlibvisio_1_1VSDCharIX.html", "classlibvisio_1_1VSDCharIX" ],
      [ "VSDCharStyle", "structlibvisio_1_1VSDCharStyle.html", "structlibvisio_1_1VSDCharStyle" ],
      [ "VSDCloseListElementOutputElement", "classlibvisio_1_1VSDCloseListElementOutputElement.html", "classlibvisio_1_1VSDCloseListElementOutputElement" ],
      [ "VSDCloseParagraphOutputElement", "classlibvisio_1_1VSDCloseParagraphOutputElement.html", "classlibvisio_1_1VSDCloseParagraphOutputElement" ],
      [ "VSDCloseSpanOutputElement", "classlibvisio_1_1VSDCloseSpanOutputElement.html", "classlibvisio_1_1VSDCloseSpanOutputElement" ],
      [ "VSDCloseUnorderedListLevelOutputElement", "classlibvisio_1_1VSDCloseUnorderedListLevelOutputElement.html", "classlibvisio_1_1VSDCloseUnorderedListLevelOutputElement" ],
      [ "VSDCollector", "classlibvisio_1_1VSDCollector.html", "classlibvisio_1_1VSDCollector" ],
      [ "VSDContentCollector", "classlibvisio_1_1VSDContentCollector.html", "classlibvisio_1_1VSDContentCollector" ],
      [ "VSDDummyDeleter", "structlibvisio_1_1VSDDummyDeleter.html", "structlibvisio_1_1VSDDummyDeleter" ],
      [ "VSDEllipse", "classlibvisio_1_1VSDEllipse.html", "classlibvisio_1_1VSDEllipse" ],
      [ "VSDEllipticalArcTo", "classlibvisio_1_1VSDEllipticalArcTo.html", "classlibvisio_1_1VSDEllipticalArcTo" ],
      [ "VSDEmpty", "classlibvisio_1_1VSDEmpty.html", "classlibvisio_1_1VSDEmpty" ],
      [ "VSDEndLayerOutputElement", "classlibvisio_1_1VSDEndLayerOutputElement.html", "classlibvisio_1_1VSDEndLayerOutputElement" ],
      [ "VSDEndTextObjectOutputElement", "classlibvisio_1_1VSDEndTextObjectOutputElement.html", "classlibvisio_1_1VSDEndTextObjectOutputElement" ],
      [ "VSDFieldList", "classlibvisio_1_1VSDFieldList.html", "classlibvisio_1_1VSDFieldList" ],
      [ "VSDFieldListElement", "classlibvisio_1_1VSDFieldListElement.html", "classlibvisio_1_1VSDFieldListElement" ],
      [ "VSDFillStyle", "structlibvisio_1_1VSDFillStyle.html", "structlibvisio_1_1VSDFillStyle" ],
      [ "VSDFont", "structlibvisio_1_1VSDFont.html", "structlibvisio_1_1VSDFont" ],
      [ "VSDGeometry", "classlibvisio_1_1VSDGeometry.html", "classlibvisio_1_1VSDGeometry" ],
      [ "VSDGeometryList", "classlibvisio_1_1VSDGeometryList.html", "classlibvisio_1_1VSDGeometryList" ],
      [ "VSDGeometryListElement", "classlibvisio_1_1VSDGeometryListElement.html", "classlibvisio_1_1VSDGeometryListElement" ],
      [ "VSDGraphicObjectOutputElement", "classlibvisio_1_1VSDGraphicObjectOutputElement.html", "classlibvisio_1_1VSDGraphicObjectOutputElement" ],
      [ "VSDInfiniteLine", "classlibvisio_1_1VSDInfiniteLine.html", "classlibvisio_1_1VSDInfiniteLine" ],
      [ "VSDInsertLineBreakOutputElement", "classlibvisio_1_1VSDInsertLineBreakOutputElement.html", "classlibvisio_1_1VSDInsertLineBreakOutputElement" ],
      [ "VSDInsertTabOutputElement", "classlibvisio_1_1VSDInsertTabOutputElement.html", "classlibvisio_1_1VSDInsertTabOutputElement" ],
      [ "VSDInsertTextOutputElement", "classlibvisio_1_1VSDInsertTextOutputElement.html", "classlibvisio_1_1VSDInsertTextOutputElement" ],
      [ "VSDLayer", "structlibvisio_1_1VSDLayer.html", "structlibvisio_1_1VSDLayer" ],
      [ "VSDLayerList", "classlibvisio_1_1VSDLayerList.html", "classlibvisio_1_1VSDLayerList" ],
      [ "VSDLineStyle", "structlibvisio_1_1VSDLineStyle.html", "structlibvisio_1_1VSDLineStyle" ],
      [ "VSDLineTo", "classlibvisio_1_1VSDLineTo.html", "classlibvisio_1_1VSDLineTo" ],
      [ "VSDMetaData", "classlibvisio_1_1VSDMetaData.html", "classlibvisio_1_1VSDMetaData" ],
      [ "VSDMisc", "structlibvisio_1_1VSDMisc.html", "structlibvisio_1_1VSDMisc" ],
      [ "VSDMoveTo", "classlibvisio_1_1VSDMoveTo.html", "classlibvisio_1_1VSDMoveTo" ],
      [ "VSDName", "classlibvisio_1_1VSDName.html", "classlibvisio_1_1VSDName" ],
      [ "VSDNumericField", "classlibvisio_1_1VSDNumericField.html", "classlibvisio_1_1VSDNumericField" ],
      [ "VSDNURBSTo1", "classlibvisio_1_1VSDNURBSTo1.html", "classlibvisio_1_1VSDNURBSTo1" ],
      [ "VSDNURBSTo2", "classlibvisio_1_1VSDNURBSTo2.html", "classlibvisio_1_1VSDNURBSTo2" ],
      [ "VSDNURBSTo3", "classlibvisio_1_1VSDNURBSTo3.html", "classlibvisio_1_1VSDNURBSTo3" ],
      [ "VSDOpenListElementOutputElement", "classlibvisio_1_1VSDOpenListElementOutputElement.html", "classlibvisio_1_1VSDOpenListElementOutputElement" ],
      [ "VSDOpenParagraphOutputElement", "classlibvisio_1_1VSDOpenParagraphOutputElement.html", "classlibvisio_1_1VSDOpenParagraphOutputElement" ],
      [ "VSDOpenSpanOutputElement", "classlibvisio_1_1VSDOpenSpanOutputElement.html", "classlibvisio_1_1VSDOpenSpanOutputElement" ],
      [ "VSDOpenUnorderedListLevelOutputElement", "classlibvisio_1_1VSDOpenUnorderedListLevelOutputElement.html", "classlibvisio_1_1VSDOpenUnorderedListLevelOutputElement" ],
      [ "VSDOptionalCharStyle", "structlibvisio_1_1VSDOptionalCharStyle.html", "structlibvisio_1_1VSDOptionalCharStyle" ],
      [ "VSDOptionalFillStyle", "structlibvisio_1_1VSDOptionalFillStyle.html", "structlibvisio_1_1VSDOptionalFillStyle" ],
      [ "VSDOptionalLineStyle", "structlibvisio_1_1VSDOptionalLineStyle.html", "structlibvisio_1_1VSDOptionalLineStyle" ],
      [ "VSDOptionalParaStyle", "structlibvisio_1_1VSDOptionalParaStyle.html", "structlibvisio_1_1VSDOptionalParaStyle" ],
      [ "VSDOptionalTextBlockStyle", "structlibvisio_1_1VSDOptionalTextBlockStyle.html", "structlibvisio_1_1VSDOptionalTextBlockStyle" ],
      [ "VSDOutputElement", "classlibvisio_1_1VSDOutputElement.html", "classlibvisio_1_1VSDOutputElement" ],
      [ "VSDOutputElementList", "classlibvisio_1_1VSDOutputElementList.html", "classlibvisio_1_1VSDOutputElementList" ],
      [ "VSDPage", "classlibvisio_1_1VSDPage.html", "classlibvisio_1_1VSDPage" ],
      [ "VSDPages", "classlibvisio_1_1VSDPages.html", "classlibvisio_1_1VSDPages" ],
      [ "VSDParagraphList", "classlibvisio_1_1VSDParagraphList.html", "classlibvisio_1_1VSDParagraphList" ],
      [ "VSDParagraphListElement", "classlibvisio_1_1VSDParagraphListElement.html", "classlibvisio_1_1VSDParagraphListElement" ],
      [ "VSDParaIX", "classlibvisio_1_1VSDParaIX.html", "classlibvisio_1_1VSDParaIX" ],
      [ "VSDParaStyle", "structlibvisio_1_1VSDParaStyle.html", "structlibvisio_1_1VSDParaStyle" ],
      [ "VSDParser", "classlibvisio_1_1VSDParser.html", "classlibvisio_1_1VSDParser" ],
      [ "VSDPathOutputElement", "classlibvisio_1_1VSDPathOutputElement.html", "classlibvisio_1_1VSDPathOutputElement" ],
      [ "VSDPolylineTo1", "classlibvisio_1_1VSDPolylineTo1.html", "classlibvisio_1_1VSDPolylineTo1" ],
      [ "VSDPolylineTo2", "classlibvisio_1_1VSDPolylineTo2.html", "classlibvisio_1_1VSDPolylineTo2" ],
      [ "VSDPolylineTo3", "classlibvisio_1_1VSDPolylineTo3.html", "classlibvisio_1_1VSDPolylineTo3" ],
      [ "VSDRelCubBezTo", "classlibvisio_1_1VSDRelCubBezTo.html", "classlibvisio_1_1VSDRelCubBezTo" ],
      [ "VSDRelEllipticalArcTo", "classlibvisio_1_1VSDRelEllipticalArcTo.html", "classlibvisio_1_1VSDRelEllipticalArcTo" ],
      [ "VSDRelLineTo", "classlibvisio_1_1VSDRelLineTo.html", "classlibvisio_1_1VSDRelLineTo" ],
      [ "VSDRelMoveTo", "classlibvisio_1_1VSDRelMoveTo.html", "classlibvisio_1_1VSDRelMoveTo" ],
      [ "VSDRelQuadBezTo", "classlibvisio_1_1VSDRelQuadBezTo.html", "classlibvisio_1_1VSDRelQuadBezTo" ],
      [ "VSDShape", "classlibvisio_1_1VSDShape.html", "classlibvisio_1_1VSDShape" ],
      [ "VSDShapeList", "classlibvisio_1_1VSDShapeList.html", "classlibvisio_1_1VSDShapeList" ],
      [ "VSDSplineKnot", "classlibvisio_1_1VSDSplineKnot.html", "classlibvisio_1_1VSDSplineKnot" ],
      [ "VSDSplineStart", "classlibvisio_1_1VSDSplineStart.html", "classlibvisio_1_1VSDSplineStart" ],
      [ "VSDStartLayerOutputElement", "classlibvisio_1_1VSDStartLayerOutputElement.html", "classlibvisio_1_1VSDStartLayerOutputElement" ],
      [ "VSDStartTextObjectOutputElement", "classlibvisio_1_1VSDStartTextObjectOutputElement.html", "classlibvisio_1_1VSDStartTextObjectOutputElement" ],
      [ "VSDStencil", "classlibvisio_1_1VSDStencil.html", "classlibvisio_1_1VSDStencil" ],
      [ "VSDStencils", "classlibvisio_1_1VSDStencils.html", "classlibvisio_1_1VSDStencils" ],
      [ "VSDStyleOutputElement", "classlibvisio_1_1VSDStyleOutputElement.html", "classlibvisio_1_1VSDStyleOutputElement" ],
      [ "VSDStyles", "classlibvisio_1_1VSDStyles.html", "classlibvisio_1_1VSDStyles" ],
      [ "VSDStylesCollector", "classlibvisio_1_1VSDStylesCollector.html", "classlibvisio_1_1VSDStylesCollector" ],
      [ "VSDTabSet", "structlibvisio_1_1VSDTabSet.html", "structlibvisio_1_1VSDTabSet" ],
      [ "VSDTabStop", "structlibvisio_1_1VSDTabStop.html", "structlibvisio_1_1VSDTabStop" ],
      [ "VSDTextBlockStyle", "structlibvisio_1_1VSDTextBlockStyle.html", "structlibvisio_1_1VSDTextBlockStyle" ],
      [ "VSDTextField", "classlibvisio_1_1VSDTextField.html", "classlibvisio_1_1VSDTextField" ],
      [ "VSDXClrScheme", "structlibvisio_1_1VSDXClrScheme.html", "structlibvisio_1_1VSDXClrScheme" ],
      [ "VSDXFont", "structlibvisio_1_1VSDXFont.html", "structlibvisio_1_1VSDXFont" ],
      [ "VSDXFontScheme", "structlibvisio_1_1VSDXFontScheme.html", "structlibvisio_1_1VSDXFontScheme" ],
      [ "VSDXMetaData", "classlibvisio_1_1VSDXMetaData.html", "classlibvisio_1_1VSDXMetaData" ],
      [ "VSDXMLParserBase", "classlibvisio_1_1VSDXMLParserBase.html", "classlibvisio_1_1VSDXMLParserBase" ],
      [ "VSDXMLTokenMap", "classlibvisio_1_1VSDXMLTokenMap.html", "classlibvisio_1_1VSDXMLTokenMap" ],
      [ "VSDXParser", "classlibvisio_1_1VSDXParser.html", "classlibvisio_1_1VSDXParser" ],
      [ "VSDXRelationship", "classlibvisio_1_1VSDXRelationship.html", "classlibvisio_1_1VSDXRelationship" ],
      [ "VSDXRelationships", "classlibvisio_1_1VSDXRelationships.html", "classlibvisio_1_1VSDXRelationships" ],
      [ "VSDXTheme", "classlibvisio_1_1VSDXTheme.html", "classlibvisio_1_1VSDXTheme" ],
      [ "VSDXVariationClrScheme", "structlibvisio_1_1VSDXVariationClrScheme.html", "structlibvisio_1_1VSDXVariationClrScheme" ],
      [ "VSDXVariationStyleScheme", "structlibvisio_1_1VSDXVariationStyleScheme.html", "structlibvisio_1_1VSDXVariationStyleScheme" ],
      [ "XForm", "structlibvisio_1_1XForm.html", "structlibvisio_1_1XForm" ],
      [ "XForm1D", "structlibvisio_1_1XForm1D.html", "structlibvisio_1_1XForm1D" ],
      [ "XMLErrorWatcher", "classlibvisio_1_1XMLErrorWatcher.html", "classlibvisio_1_1XMLErrorWatcher" ],
      [ "XmlParserException", "classlibvisio_1_1XmlParserException.html", null ]
    ] ],
    [ "Perfect_Hash", "classPerfect__Hash.html", "classPerfect__Hash" ],
    [ "VSDInternalStream", "classVSDInternalStream.html", "classVSDInternalStream" ],
    [ "xmltoken", "structxmltoken.html", "structxmltoken" ]
];

==> libvisio-0.1.10-3-x86_64.pkg.tar.zst: usr/share/doc/libvisio/html/annotated_dup.js <==
var annotated_dup =
[
    [ "libvisio", "namespacelibvisio.html", [
      [ "VSDDummyDeleter", "structlibvisio_1_1VSDDummyDeleter.html", "structlibvisio_1_1VSDDummyDeleter" ],
      [ "EndOfStreamException", "classlibvisio_1_1EndOfStreamException.html", null ],
      [ "XmlParserException", "classlibvisio_1_1XmlParserException.html", null ],
      [ "GenericException", "classlibvisio_1_1GenericException.html", null ],
      [ "XMLErrorWatcher", "classlibvisio_1_1XMLErrorWatcher.html", "classlibvisio_1_1XMLErrorWatcher" ],
      [ "VDXParser", "classlibvisio_1_1VDXParser.html", "classlibvisio_1_1VDXParser" ],
      [ "VSD5Parser", "classlibvisio_1_1VSD5Parser.html", "classlibvisio_1_1VSD5Parser" ],
      [ "VSD6Parser", "classlibvisio_1_1VSD6Parser.html", "classlibvisio_1_1VSD6Parser" ],
      [ "VSDCharacterListElement", "classlibvisio_1_1VSDCharacterListElement.html", "classlibvisio_1_1VSDCharacterListElement" ],
      [ "VSDCharIX", "classlibvisio_1_1VSDCharIX.html", "classlibvisio_1_1VSDCharIX" ],
      [ "VSDCharacterList", "classlibvisio_1_1VSDCharacterList.html", "classlibvisio_1_1VSDCharacterList" ],
      [ "VSDCollector", "classlibvisio_1_1VSDCollector.html", "classlibvisio_1_1VSDCollector" ],
      [ "VSDContentCollector", "classlibvisio_1_1VSDContentCollector.html", "classlibvisio_1_1VSDContentCollector" ],
      [ "VSDFieldListElement", "classlibvisio_1_1VSDFieldListElement.html", "classlibvisio_1_1VSDFieldListElement" ],
      [ "VSDTextField", "classlibvisio_1_1VSDTextField.html", "classlibvisio_1_1VSDTextField" ],
      [ "VSDNumericField", "classlibvisio_1_1VSDNumericField.html", "classlibvisio_1_1VSDNumericField" ],
      [ "VSDFieldList", "classlibvisio_1_1VSDFieldList.html", "classlibvisio_1_1VSDFieldList" ],
      [ "VSDGeometry", "classlibvisio_1_1VSDGeometry.html", "classlibvisio_1_1VSDGeometry" ],
      [ "VSDEmpty", "classlibvisio_1_1VSDEmpty.html", "classlibvisio_1_1VSDEmpty" ],
      [ "VSDMoveTo", "classlibvisio_1_1VSDMoveTo.html", "classlibvisio_1_1VSDMoveTo" ],
      [ "VSDLineTo", "classlibvisio_1_1VSDLineTo.html", "classlibvisio_1_1VSDLineTo" ],
      [ "VSDArcTo", "classlibvisio_1_1VSDArcTo.html", "classlibvisio_1_1VSDArcTo" ],
      [ "VSDEllipse", "classlibvisio_1_1VSDEllipse.html", "classlibvisio_1_1VSDEllipse" ],
      [ "VSDEllipticalArcTo", "classlibvisio_1_1VSDEllipticalArcTo.html", "classlibvisio_1_1VSDEllipticalArcTo" ],
      [ "VSDNURBSTo1", "classlibvisio_1_1VSDNURBSTo1.html", "classlibvisio_1_1VSDNURBSTo1" ],
      [ "VSDNURBSTo2", "classlibvisio_1_1VSDNURBSTo2.html", "classlibvisio_1_1VSDNURBSTo2" ],
      [ "VSDNURBSTo3", "classlibvisio_1_1VSDNURBSTo3.html", "classlibvisio_1_1VSDNURBSTo3" ],
      [ "VSDPolylineTo1", "classlibvisio_1_1VSDPolylineTo1.html", "classlibvisio_1_1VSDPolylineTo1" ],
      [ "VSDPolylineTo2", "classlibvisio_1_1VSDPolylineTo2.html", "classlibvisio_1_1VSDPolylineTo2" ],
      [ "VSDPolylineTo3", "classlibvisio_1_1VSDPolylineTo3.html", "classlibvisio_1_1VSDPolylineTo3" ],
      [ "VSDSplineStart", "classlibvisio_1_1VSDSplineStart.html", "classlibvisio_1_1VSDSplineStart" ],
      [ "VSDSplineKnot", "classlibvisio_1_1VSDSplineKnot.html", "classlibvisio_1_1VSDSplineKnot" ],
      [ "VSDInfiniteLine", "classlibvisio_1_1VSDInfiniteLine.html", "classlibvisio_1_1VSDInfiniteLine" ],
      [ "VSDRelCubBezTo", "classlibvisio_1_1VSDRelCubBezTo.html", "classlibvisio_1_1VSDRelCubBezTo" ],
      [ "VSDRelEllipticalArcTo", "classlibvisio_1_1VSDRelEllipticalArcTo.html", "classlibvisio_1_1VSDRelEllipticalArcTo" ],
      [ "VSDRelMoveTo", "classlibvisio_1_1VSDRelMoveTo.html", "classlibvisio_1_1VSDRelMoveTo" ],
      [ "VSDRelLineTo", "classlibvisio_1_1VSDRelLineTo.html", "classlibvisio_1_1VSDRelLineTo" ],
      [ "VSDRelQuadBezTo", "classlibvisio_1_1VSDRelQuadBezTo.html", "classlibvisio_1_1VSDRelQuadBezTo" ],
      [ "VSDGeometryListElement", "classlibvisio_1_1VSDGeometryListElement.html", "classlibvisio_1_1VSDGeometryListElement" ],
      [ "VSDGeometryList", "classlibvisio_1_1VSDGeometryList.html", "classlibvisio_1_1VSDGeometryList" ],
      [ "VSDLayer", "structlibvisio_1_1VSDLayer.html", "structlibvisio_1_1VSDLayer" ],
      [ "VSDLayerList", "classlibvisio_1_1VSDLayerList.html", "classlibvisio_1_1VSDLayerList" ],
      [ "VSDMetaData", "classlibvisio_1_1VSDMetaData.html", "classlibvisio_1_1VSDMetaData" ],
      [ "VSDOutputElement", "classlibvisio_1_1VSDOutputElement.html", "classlibvisio_1_1VSDOutputElement" ],
      [ "VSDStyleOutputElement", "classlibvisio_1_1VSDStyleOutputElement.html", "classlibvisio_1_1VSDStyleOutputElement" ],
      [ "VSDPathOutputElement", "classlibvisio_1_1VSDPathOutputElement.html", "classlibvisio_1_1VSDPathOutputElement" ],
      [ "VSDGraphicObjectOutputElement", "classlibvisio_1_1VSDGraphicObjectOutputElement.html", "classlibvisio_1_1VSDGraphicObjectOutputElement" ],
      [ "VSDStartTextObjectOutputElement", "classlibvisio_1_1VSDStartTextObjectOutputElement.html", "classlibvisio_1_1VSDStartTextObjectOutputElement" ],
      [ "VSDOpenParagraphOutputElement", "classlibvisio_1_1VSDOpenParagraphOutputElement.html", "classlibvisio_1_1VSDOpenParagraphOutputElement" ],
      [ "VSDStartLayerOutputElement", "classlibvisio_1_1VSDStartLayerOutputElement.html", "classlibvisio_1_1VSDStartLayerOutputElement" ],
      [ "VSDEndLayerOutputElement", "classlibvisio_1_1VSDEndLayerOutputElement.html", "classlibvisio_1_1VSDEndLayerOutputElement" ],
      [ "VSDOpenSpanOutputElement", "classlibvisio_1_1VSDOpenSpanOutputElement.html", "classlibvisio_1_1VSDOpenSpanOutputElement" ],
      [ "VSDInsertTextOutputElement", "classlibvisio_1_1VSDInsertTextOutputElement.html", "classlibvisio_1_1VSDInsertTextOutputElement" ],
      [ "VSDInsertLineBreakOutputElement", "classlibvisio_1_1VSDInsertLineBreakOutputElement.html", "classlibvisio_1_1VSDInsertLineBreakOutputElement" ],
      [ "VSDInsertTabOutputElement", "classlibvisio_1_1VSDInsertTabOutputElement.html", "classlibvisio_1_1VSDInsertTabOutputElement" ],
      [ "VSDCloseSpanOutputElement", "classlibvisio_1_1VSDCloseSpanOutputElement.html", "classlibvisio_1_1VSDCloseSpanOutputElement" ],
      [ "VSDCloseParagraphOutputElement", "classlibvisio_1_1VSDCloseParagraphOutputElement.html", "classlibvisio_1_1VSDCloseParagraphOutputElement" ],
      [ "VSDEndTextObjectOutputElement", "classlibvisio_1_1VSDEndTextObjectOutputElement.html", "classlibvisio_1_1VSDEndTextObjectOutputElement" ],
      [ "VSDOpenListElementOutputElement", "classlibvisio_1_1VSDOpenListElementOutputElement.html", "classlibvisio_1_1VSDOpenListElementOutputElement" ],
      [ "VSDCloseListElementOutputElement", "classlibvisio_1_1VSDCloseListElementOutputElement.html", "classlibvisio_1_1VSDCloseListElementOutputElement" ],
      [ "VSDOpenUnorderedListLevelOutputElement", "classlibvisio_1_1VSDOpenUnorderedListLevelOutputElement.html", "classlibvisio_1_1VSDOpenUnorderedListLevelOutputElement" ],
      [ "VSDCloseUnorderedListLevelOutputElement", "classlibvisio_1_1VSDCloseUnorderedListLevelOutputElement.html", "classlibvisio_1_1VSDCloseUnorderedListLevelOutputElement" ],
      [ "VSDOutputElementList", "classlibvisio_1_1VSDOutputElementList.html", "classlibvisio_1_1VSDOutputElementList" ],
      [ "VSDPage", "classlibvisio_1_1VSDPage.html", "classlibvisio_1_1VSDPage" ],
      [ "VSDPages", "classlibvisio_1_1VSDPages.html", "classlibvisio_1_1VSDPages" ],
      [ "VSDParagraphListElement", "classlibvisio_1_1VSDParagraphListElement.html", "classlibvisio_1_1VSDParagraphListElement" ],
      [ "VSDParaIX", "classlibvisio_1_1VSDParaIX.html", "classlibvisio_1_1VSDParaIX" ],
      [ "VSDParagraphList", "classlibvisio_1_1VSDParagraphList.html", "classlibvisio_1_1VSDParagraphList" ],
      [ "Pointer", "structlibvisio_1_1Pointer.html", "structlibvisio_1_1Pointer" ],
      [ "VSDParser", "classlibvisio_1_1VSDParser.html", "classlibvisio_1_1VSDParser" ],
      [ "VSDShapeList", "classlibvisio_1_1VSDShapeList.html", "classlibvisio_1_1VSDShapeList" ],
      [ "VSDShape", "classlibvisio_1_1VSDShape.html", "classlibvisio_1_1VSDShape" ],
      [ "VSDStencil", "classlibvisio_1_1VSDStencil.html", "classlibvisio_1_1VSDStencil" ],
      [ "VSDStencils", "classlibvisio_1_1VSDStencils.html", "classlibvisio_1_1VSDStencils" ],
      [ "VSDOptionalLineStyle", "structlibvisio_1_1VSDOptionalLineStyle.html", "structlibvisio_1_1VSDOptionalLineStyle" ],
      [ "VSDLineStyle", "structlibvisio_1_1VSDLineStyle.html", "structlibvisio_1_1VSDLineStyle" ],
      [ "VSDOptionalFillStyle", "structlibvisio_1_1VSDOptionalFillStyle.html", "structlibvisio_1_1VSDOptionalFillStyle" ],
      [ "VSDFillStyle", "structlibvisio_1_1VSDFillStyle.html", "structlibvisio_1_1VSDFillStyle" ],
      [ "VSDOptionalCharStyle", "structlibvisio_1_1VSDOptionalCharStyle.html", "structlibvisio_1_1VSDOptionalCharStyle" ],
      [ "VSDCharStyle", "structlibvisio_1_1VSDCharStyle.html", "structlibvisio_1_1VSDCharStyle" ],
      [ "VSDOptionalParaStyle", "structlibvisio_1_1VSDOptionalParaStyle.html", "structlibvisio_1_1VSDOptionalParaStyle" ],
      [ "VSDParaStyle", "structlibvisio_1_1VSDParaStyle.html", "structlibvisio_1_1VSDParaStyle" ],
      [ "VSDOptionalTextBlockStyle", "structlibvisio_1_1VSDOptionalTextBlockStyle.html", "structlibvisio_1_1VSDOptionalTextBlockStyle" ],
      [ "VSDTextBlockStyle", "structlibvisio_1_1VSDTextBlockStyle.html", "structlibvisio_1_1VSDTextBlockStyle" ],
      [ "VSDStyles", "classlibvisio_1_1VSDStyles.html", "classlibvisio_1_1VSDStyles" ],
      [ "VSDStylesCollector", "classlibvisio_1_1VSDStylesCollector.html", "classlibvisio_1_1VSDStylesCollector" ],
      [ "XForm", "structlibvisio_1_1XForm.html", "structlibvisio_1_1XForm" ],
      [ "XForm1D", "structlibvisio_1_1XForm1D.html", "structlibvisio_1_1XForm1D" ],
      [ "ChunkHeader", "structlibvisio_1_1ChunkHeader.html", "structlibvisio_1_1ChunkHeader" ],
      [ "Colour", "structlibvisio_1_1Colour.html", "structlibvisio_1_1Colour" ],
      [ "NURBSData", "structlibvisio_1_1NURBSData.html", "structlibvisio_1_1NURBSData" ],
      [ "PolylineData", "structlibvisio_1_1PolylineData.html", "structlibvisio_1_1PolylineData" ],
      [ "ForeignData", "structlibvisio_1_1ForeignData.html", "structlibvisio_1_1ForeignData" ],
      [ "VSDName", "classlibvisio_1_1VSDName.html", "classlibvisio_1_1VSDName" ],
      [ "VSDFont", "structlibvisio_1_1VSDFont.html", "structlibvisio_1_1VSDFont" ],
      [ "VSDMisc", "structlibvisio_1_1VSDMisc.html", "structlibvisio_1_1VSDMisc" ],
      [ "VSDTabStop", "structlibvisio_1_1VSDTabStop.html", "structlibvisio_1_1VSDTabStop" ],
      [ "VSDTabSet", "structlibvisio_1_1VSDTabSet.html", "structlibvisio_1_1VSDTabSet" ],
      [ "VSDBullet", "structlibvisio_1_1VSDBullet.html", "structlibvisio_1_1VSDBullet" ],
      [ "VSDXMetaData", "classlibvisio_1_1VSDXMetaData.html", "classlibvisio_1_1VSDXMetaData" ],
      [ "VSDXRelationship", "classlibvisio_1_1VSDXRelationship.html", "classlibvisio_1_1VSDXRelationship" ],
      [ "VSDXRelationships", "classlibvisio_1_1VSDXRelationships.html", "classlibvisio_1_1VSDXRelationships" ],
      [ "VSDXMLParserBase", "classlibvisio_1_1VSDXMLParserBase.html", "classlibvisio_1_1VSDXMLParserBase" ],
      [ "VSDXMLTokenMap", "classlibvisio_1_1VSDXMLTokenMap.html", "classlibvisio_1_1VSDXMLTokenMap" ],
      [ "VSDXParser", "classlibvisio_1_1VSDXParser.html", "classlibvisio_1_1VSDXParser" ],
      [ "VSDXVariationClrScheme", "structlibvisio_1_1VSDXVariationClrScheme.html", "structlibvisio_1_1VSDXVariationClrScheme" ],
      [ "VSDXClrScheme", "structlibvisio_1_1VSDXClrScheme.html", "structlibvisio_1_1VSDXClrScheme" ],
      [ "VSDXFont", "structlibvisio_1_1VSDXFont.html", "structlibvisio_1_1VSDXFont" ],
      [ "VSDXFontScheme", "structlibvisio_1_1VSDXFontScheme.html", "structlibvisio_1_1VSDXFontScheme" ],
      [ "VSDXVariationStyleScheme", "structlibvisio_1_1VSDXVariationStyleScheme.html", "structlibvisio_1_1VSDXVariationStyleScheme" ],
      [ "VSDXTheme", "classlibvisio_1_1VSDXTheme.html", "classlibvisio_1_1VSDXTheme" ],
      [ "VisioDocument", "classlibvisio_1_1VisioDocument.html", "classlibvisio_1_1VisioDocument" ]
    ] ],
    [ "Perfect_Hash", "classPerfect__Hash.html", "classPerfect__Hash" ],
    [ "VSDInternalStream", "classVSDInternalStream.html", "classVSDInternalStream" ],
    [ "xmltoken", "structxmltoken.html", "structxmltoken" ]
];
